Latest version 4.0

For the impatient:

1. Create a virtual Python environment in your OS: python -m venv venv
2. activate it by typing  : source venv/bin/activate
3. pip install bsg-ide
4. bsg-ide --fix

Your file menu should now show the bsg-ide icon under the office menu.

OR

1. Download the files.
2. Unzip it
3. run:> python BSG-IDE.py --fix
4. Now from menu, you can load BSG-IDE (usually under Office folder)

# Bridge the gap between Idea Generation and PDF Presentation

Create a presentation slide in no time. That is the goal. Read the manual (RTM!) Contact me (nsp@airis4d.com) for clarifications. Contribute to the manual by adding your observations. AND Enjoy!

### A good talk means a well-organised flow of ideas. However, it is not as easy as we say. The human brain brings ideas in bits and pieces and processes them in parallel. Mind mapping software usually provides a platform to convert these pieces into an organised sequence of ideas necessary for a good talk. Many mind mapping software allows direct translation of the maps into Latex files, simplifying the conversion task. However, one may want to use packages like Beamer to make the presentation impressive. The presentation is usually a suitable PDF file because it allows cross-platform compatibility. The problem with PDF presentations is that they typically discard the flexibility to use speaker notes, an attraction of PowerPoint presentations using LibreOffice or Microsoft Office. Thankfully, there is an excellent package for making dual-screen presentations with notes that work across different platforms, known as pympress in the open source, with all the features the alternative platforms offer and more! Great. So the question is - can we have a tool that bridges the gap from idea generation to PDF presentation all under one umbrella? That is what Beamer Slide Generator and its IDE BSG-IDE are all about. Please use, share and Contribute to the development. It is in the Open Source.

Update:  BSG-IDE.py  is a complete development IDE that creates the text file and all intermediate steps to generate PDF presentation output. The IDE also provides a preamble editor that allows you to customise the look and feel of your presentation. I encourage users to upload their contributions to appealing preamble setup files under the Creative Commons licence to make the product versatile.

NOTE: You need not worry about creating the text file. That is the good news. You give a new file name, say <some_filename>.txt, after selecting the option 2. It will guide you through even suggestive pages on your browser related to the topic of your slide. You can follow the instructions. Copy and paste YouTube video links by selecting option 1 in the submenu, or add your own files by selecting option 2. No worries, the links will be automatically cited so that you won't be blamed for IP violation. Try it and let me know.
